AGENT_ACTIVE_MODE = 'STOOBLY_AGENT_ACTIVE_MODE'
AGENT_CONFIG_PATH = 'STOOBLY_AGENT_CONFIG_PATH'
AGENT_ENABLED = 'STOOBLY_AGENT_ENABLED'
AGENT_IS_HEADLESS = 'STOOBLY_AGENT_IS_HEADLESS'
AGENT_INCLUDE_PATTERNS = 'STOOBLY_AGENT_INCLUDE_PATTERNS'
AGENT_EXCLUDE_PATTERNS = 'STOOBLY_AGENT_EXCLUDE_PATTERNS'
AGENT_POLICY = 'STOOBLY_AGENT_POLICY'
AGENT_PROJECT_KEY = 'STOOBLY_AGENT_PROJECT_KEY'
AGENT_PROXY_URL = 'STOOBLY_AGENT_PROXY_URL'
AGENT_REMOTE_ENABLED = 'STOOBLY_AGENT_REMOTE_ENABLED'
AGENT_SERVICE_URL = 'STOOBLY_AGENT_SERVICE_URL'
AGENT_SCENARIO_KEY = 'STOOBLY_AGENT_SCENARIO_KEY'
AGENT_URL = 'STOOBLY_AGENT_URL'
API_URL = 'STOOBLY_API_URL'
API_KEY = 'STOOBLY_API_KEY'
ENV = 'STOOBY_AGENT_ENV'
HTTP_PROXY = 'HTTP_PROXY'
HTTPS_PROXY = 'HTTPS_PROXY'
LOG_LEVEL = 'STOOBLY_AGENT_LOG_LEVEL'
NO_PROXY = 'NO_PROXY'